@@ -5,7 +5,7 @@ use warnings;
 
 package Git::Gerrit;
 {
-  $Git::Gerrit::VERSION = '0.001';
+  $Git::Gerrit::VERSION = '0.002';
 }
 # ABSTRACT: Git extension to implement a Gerrit workflow
 
@@ -399,7 +399,7 @@ $Commands{new} = sub {
         or die "new: the topic name ($topic) should not contain slashes.\n";
 
     $topic =~ m:\D:
-        or die "new: the topic name ($topic) should contain at lease one non-digit character.\n";
+        or die "new: the topic name ($topic) should contain at least one non-digit character.\n";
 
     my $branch = shift @ARGV || current_branch;
 
@@ -836,7 +836,7 @@ Git::Gerrit - Git extension to implement a Gerrit workflow
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
